
struct conf * SgetScon(void);
void Ssetgate(u_long);
void Ssetname(u_long);
u_long Sgetname(void);
u_char *Sgetdomain(void);
int Sdominit(void);
void Sdomshut(void);
u_long Sgetbroadcast(void);
void Sgetether(u_char *);
int Snetinit(void);
void Snetshut(void);
int Socket(u_char, struct sockaddr *, u_int, struct port *);
int SoBind(int, struct sockaddr *);
int SoListen(int);
int SoAccept(int, struct sockaddr *);
int SoReceive(int, struct sockaddr *, u_char *, u_int);
int SoSend(int, struct sockaddr *, u_char *, u_int);
int SoConnect(int, struct sockaddr *);
int SoRead(int, u_char *, u_int);
int SoWrite(int, u_char *, u_int);
int SoClose(int);
void SoFree(int);
struct ebuf *Sgeteb(void);
void netsleep(void);
